//**********
// Arg functions Version 1.0
//
// The "Arg" functions process a string (ArgStr) in URL argument list format.
// Most of them take an ArgStr and other parameters, process it, and give back
// a value (like getArg) or another ArgStr if the process will modify the
// ArgStr (like putArg()).


// Convert a plane argument into arglist format
function encodeArg(arg)
{
	var ret = arg;
	ret = ret.replace(/#/g, '%23');
	ret = ret.replace(/&/g, '%26');
	ret = ret.replace(/'/g, '%27');
	ret = ret.replace(/\(/g, '%28');
	ret = ret.replace(/\)/g, '%29');
	ret = ret.replace(/\//g, '%2F');
	ret = ret.replace(/=/g, '%3D');

	ret = ret.replace(/\+/g, '%2B');
	ret = ret.replace(/ /g, '+');

	return ret;
}


// Convert an argument in the arglist back to the plane format
function decodeArg(arg)
{
	var ret = arg;
	ret = ret.replace(/\+/g, ' ');
	ret = ret.replace(/%2B/g, '+');

	ret = ret.replace(/%3D/g, '=');
	ret = ret.replace(/%2F/g, '/');
	ret = ret.replace(/%29/g, ')');
	ret = ret.replace(/%28/g, '(');
	ret = ret.replace(/%27/g, '\'');
	ret = ret.replace(/%26/g, '&');
	ret = ret.replace(/%23/g, '#');
	return ret;
}


// Get the arglist from the URL, or if supplied a parameter, return the same (for transparancy)
function getArgStr(argStr)
{
//alert('getArgStr: argStr=[' + argStr + ']');
	var ret = '';
	if (argStr != null)
	{
		ret = argStr;
	} else
	{
		ret = window.location.search;
		ret = ret.replace(/\+/g, ' ');
		ret = ret.replace(/.*\?(.*)/, '$1');
		//ret = ret.replace(/%26/g, '&');
	}
	return ret;
}


// Count the number of arguments in the argStr
function countArg(argStr)
{
	if (argStr) return getArgStr(argStr).split(/&/).length;
	else return 0;
}


// Get the argument named argName from the argStr (if null get it from the URL)
function getArg(argName, argStr)
{
//alert('getArg: argName=[' + argName + ']');
	var argStrGot = getArgStr(argStr);
	var ret = '';
	if (argName)
	{
		argStrGot = '&' + argStrGot + '&';
		re = new RegExp('^.*&' + argName + '=([^&]*)&.*$');
		ret = argStrGot.replace(re, '$1');
		if (ret == argStrGot) ret = '';
		else ret = decodeArg(ret);
	}
	return ret;
}


// Put the value argVal into argument named argName inside the argStr
// (if null use the one from the URL) and return the modified argStr
function putArg(argName, argVal, argStr)
{
	var argStrGot = getArgStr(argStr);
	var ret = removeArg(argName, argStrGot)
	if (argName)
	{
		ret += '&' + argName + '=' + encodeArg(argVal);
		ret = ret.replace(/^&|&$/g, '');
	}
	return ret;
}


// Remove the argument named argName inside the argStr
// (if null use the one from the URL) and return the modified argStr
function removeArg(argName, argStr)
{
	var argStrGot = getArgStr(argStr);
	var ret = argStrGot;
	if (argName)
	{
		ret = '&' + ret + '&';
		re = new RegExp('&' + argName + '=[^&]*');
		ret = ret.replace(re, '');
		ret = ret.replace(/^&|&$/g, '');
	}
	return ret;
}


// Same as putArg except that the name argName is not required, and
// a generated numeric index will be used (e.g. n for the n'th argument).
// Take the argStr (if null use the one from the URL) and return the modified argStr
function pushArg(argVal, argStr)
{
	var argStrGot = getArgStr(argStr);
	var argNum = countArg(argStrGot) + 1;
	return putArg('arg' + argNum, argVal, argStrGot);
}


// Return an array containing all the keys of the arguments in the argStr
// (if null use the one from the URL)
function getArgKeys(argStr)
{
	var argStrGot = getArgStr(argStr);
	argStrGot = argStrGot.replace(/=[^=]*$/, '');
	var retArg = argStrGot.split(/=[^=]*&/);
	return retArg;
}


// Return a list of arguments from the argStr (if null use the one from the URL)
// in the specified format.  eg fmt="@key=>@value" and sep=", "
function getArgList(fmt, sep, argStr)
{
	var argStrGot = getArgStr(argStr);
	var argKeys = getArgKeys(argStrGot);
	var ret = '';
	for (i in argKeys)
	{
		argVal = getArg(argKeys[i], argStrGot);
		if (fmt)
		{
			argVal = fmt.replace(/@value/g, argVal);
			argVal = fmt.replace(/@key/g, argKeys[i]);
		}
		//argVal = argVal.replace('&', '\&');
		if (ret == '') ret = argVal;
		else ret += sep + argVal;
	}
	return ret;
}
